@@ -2,9 +2,8 @@ package Data::Validation;
 
 use 5.010001;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.18.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.19.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
-use Moo;
 use Data::Validation::Constants;
 use Data::Validation::Constraints;
 use Data::Validation::Filters;
@@ -13,6 +12,7 @@ use List::Util              qw( first );
 use Try::Tiny;
 use Unexpected::Types       qw( HashRef NonZeroPositiveInt );
 use Unexpected::Functions   qw( FieldComparison ValidationErrors );
+use Moo;
 
 has 'constraints' => is => 'ro', isa => HashRef, default => sub { {} };
 
@@ -32,58 +32,40 @@ has '_operators'  => is => 'ro', isa => HashRef, default => sub {
      '<'  => sub { $_[ 0 ] <  $_[ 1 ] },
      '<=' => sub { $_[ 0 ] <= $_[ 1 ] }, } };
 
-# Public methods
-sub check_form { # Validate all fields on a form by repeated calling check_field
-   my ($self, $prefix, $form) = @_; my @errors = (); $prefix ||= NUL;
+# Private functions
+my $_get_methods = sub {
+   return split SPC, $_[ 0 ] || NUL;
+};
 
-   ($form and ref $form eq HASH) or $self->_throw( 'Form bad hash' );
+my $_should_compare = sub {
+   return first { $_ eq 'compare' } $_get_methods->( $_[ 0 ]->{validate} );
+};
 
-   for my $name (sort keys %{ $form }) {
-      my $id = $prefix.$name; my $field = $self->fields->{ $id };
+my $_throw = sub {
+   EXCEPTION_CLASS->throw( @_ );
+};
 
-      ($field and ($field->{filters} or $field->{validate})) or next;
+# Private methods
+my $_filter = sub {
+   my ($self, $filters, $id, $value) = @_;
 
-      try   {
-         $form->{ $name } = $self->check_field( $id, $form->{ $name } );
-         __should_compare( $field )
-            and $self->_compare_fields( $prefix, $form, $name );
-      }
-      catch { push @errors, $_ };
-   }
+   for my $method ($_get_methods->( $filters )) {
+      my %attr    = ( %{ $self->filters->{ $id } || {} }, method => $method, );
+      my $dvf_obj = Data::Validation::Filters->new( %attr );
 
-   @errors and $self->_throw
-      ( class => ValidationErrors, args => \@errors, level => 2 );
-
-   return $form;
-}
-
-sub check_field { # Validate form field values
-   my ($self, $id, $value) = @_; my $field;
-
-   unless ($id and $field = $self->fields->{ $id }
-           and ($field->{filters} or $field->{validate})) {
-      $self->_throw( error => 'Field [_1] undefined', args => [ $id, $value ] );
-   }
-
-   $field->{filters}
-      and $value = $self->_filter( $field->{filters}, $id, $value );
-
-   for my $method (__get_methods( $field->{validate} )) {
-      $method eq 'compare' or $self->_validate( $method, $id, $value );
+      $value = $dvf_obj->filter_value( $value );
    }
 
    return $value;
-}
+};
 
-# Private methods
-sub _compare_fields {
+my $_compare_fields = sub {
    my ($self, $prefix, $form, $lhs_name) = @_;
 
    my $id         = $prefix.$lhs_name;
    my $constraint = $self->constraints->{ $id } || {};
    my $rhs_name   = $constraint->{other_field}
-      or $self->_throw( error => 'Constraint [_1] has no comparison field',
-                        args  => [ $id ] );
+      or $_throw->( 'Constraint [_1] has no comparison field', [ $id ] );
    my $op         = $constraint->{operator} || 'eq';
    my $lhs        = $form->{ $lhs_name } || NUL;
    my $rhs        = $form->{ $rhs_name } || NUL;
@@ -94,56 +76,70 @@ sub _compare_fields {
       $lhs_name = $self->fields->{ $prefix.$lhs_name }->{label} || $lhs_name;
       $rhs_name = $self->fields->{ $prefix.$rhs_name }->{label} || $rhs_name;
 
-      $self->_throw( class => FieldComparison,
-                     args  => [ $lhs_name, $op, $rhs_name ] );
+      $_throw->( FieldComparison, [ $lhs_name, $op, $rhs_name ] );
    }
 
    return;
-}
+};
 
-sub _filter {
-   my ($self, $filters, $id, $value) = @_;
-
-   for my $method (__get_methods( $filters )) {
-      my %attr    = ( %{ $self->filters->{ $id } || {} }, method => $method, );
-      my $dvf_obj = Data::Validation::Filters->new( %attr );
-
-      $value = $dvf_obj->filter( $value );
-   }
-
-   return $value;
-}
-
-sub _throw {
-   my $self = shift; EXCEPTION_CLASS->throw( @_ );
-}
-
-sub _validate {
+my $_validate = sub {
    my ($self, $method, $id, $value) = @_;
 
    my %attr = ( %{ $self->constraints->{ $id } || {} }, method => $method, );
    my $constraint = Data::Validation::Constraints->new( %attr );
 
-   unless ($constraint->validate( $value )) {
+   unless ($constraint->validate_value( $value )) {
      (my $class = $method) =~ s{ \A is }{}mx;
       my $name  = $self->fields->{ $id }->{label}
                || $self->fields->{ $id }->{fhelp} # Deprecated
                || $id;
 
-      $self->_throw( class => $class,
-                     args  => [ $name, $value ], level => $self->level );
+      $_throw->( sub { $class }, [ $name, $value ], level => $self->level);
    }
 
    return;
+};
+
+# Public methods
+sub check_form { # Validate all fields on a form by repeated calling check_field
+   my ($self, $prefix, $form) = @_; my @errors = (); $prefix ||= NUL;
+
+   ($form and ref $form eq HASH) or $_throw->( 'Form bad hash' );
+
+   for my $name (sort keys %{ $form }) {
+      my $id = $prefix.$name; my $field = $self->fields->{ $id };
+
+      ($field and ($field->{filters} or $field->{validate})) or next;
+
+      try   {
+         $form->{ $name } = $self->check_field( $id, $form->{ $name } );
+         $_should_compare->( $field )
+            and $self->$_compare_fields( $prefix, $form, $name );
+      }
+      catch { push @errors, $_ };
+   }
+
+   @errors and $_throw->( ValidationErrors, \@errors, level => 2 );
+
+   return $form;
 }
 
-# Private functions
-sub __get_methods {
-   return split SPC, $_[ 0 ] || NUL;
-}
+sub check_field { # Validate form field values
+   my ($self, $id, $value) = @_; my $field;
 
-sub __should_compare {
-   return first { $_ eq 'compare' } __get_methods( $_[ 0 ]->{validate} );
+   unless ($id and $field = $self->fields->{ $id }
+           and ($field->{filters} or $field->{validate})) {
+      $_throw->( 'Field [_1] undefined', [ $id, $value ] );
+   }
+
+   $field->{filters}
+      and $value = $self->$_filter( $field->{filters}, $id, $value );
+
+   for my $method ($_get_methods->( $field->{validate} )) {
+      $method eq 'compare' or $self->$_validate( $method, $id, $value );
+   }
+
+   return $value;
 }
 
 1;
@@ -152,13 +148,23 @@ __END__
 
 =pod
 
+=encoding utf8
+
+=begin html
+
+<a href="https://travis-ci.org/pjfl/p5-data-validation"><img src="https://travis-ci.org/pjfl/p5-data-validation.svg?branch=master" alt="Travis CI Badge"></a>
+<a href="http://badge.fury.io/pl/Data-Validation"><img src="https://badge.fury.io/pl/Data-Validation.svg" alt="CPAN Badge"></a>
+<a href="http://cpants.cpanauthors.org/dist/Data-Validation"><img src="http://cpants.cpanauthors.org/dist/Data-Validation.png" alt="Kwalitee Badge"></a>
+
+=end html
+
 =head1 Name
 
 Data::Validation - Filter and validate data values
 
 =head1 Version
 
-Describes version v0.18.$Rev: 1 $ of L<Data::Validation>
+Describes version v0.19.$Rev: 1 $ of L<Data::Validation>
 
 =head1 Synopsis
 
