@@ -2,19 +2,19 @@ package Data::Validation::Constraints::Date;
 
 use namespace::autoclean;
 
-use Moo;
 use Class::Usul::Time     qw( str2time );
 use Data::Validation::Constants;
 use Unexpected::Functions qw( has_exception );
+use Moo;
 
 extends q(Data::Validation::Constraints);
 
 has_exception 'ValidDate' => parents => [ 'Constraint' ],
    error   => 'Parameter [_1] value [_2] is not a valid date';
 
-around '_validate' => sub {
-   return defined str2time( $_[ 2 ] ) ? 1 : 0;
-};
+sub validate {
+   return defined str2time( $_[ 1 ] ) ? 1 : 0;
+}
 
 1;
 
